@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 """
 Module for running arbitrary tests with a __virtual__ function
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 
 def __virtual__():
