@@ -1,19 +1,16 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 This module allows you to install certificates into the windows certificate
 manager.
 
 .. code-block:: bash
 
     salt '*' certutil.add_store salt://cert.cer "TrustedPublisher"
-'''
+"""
+
 
-# Import Python Libs
-from __future__ import absolute_import, unicode_literals, print_function
-import re
 import logging
+import re
 
-# Import Salt Libs
 import salt.utils.platform
 
 log = logging.getLogger(__name__)
@@ -21,16 +18,16 @@ __virtualname__ = "certutil"
 
 
 def __virtual__():
-    '''
+    """
     Only work on Windows
-    '''
+    """
     if salt.utils.platform.is_windows():
         return __virtualname__
-    return False
+    return (False, "Module win_certutil: module only works on Windows systems.")
 
 
 def get_cert_serial(cert_file):
-    '''
+    """
     Get the serial number of a certificate file
 
     cert_file
@@ -41,9 +38,9 @@ def get_cert_serial(cert_file):
     .. code-block:: bash
 
         salt '*' certutil.get_cert_serial <certificate name>
-    '''
-    cmd = "certutil.exe -silent -verify {0}".format(cert_file)
-    out = __salt__['cmd.run'](cmd)
+    """
+    cmd = "certutil.exe -silent -verify {}".format(cert_file)
+    out = __salt__["cmd.run"](cmd)
     # match serial number by paragraph to work with multiple languages
     matches = re.search(r":\s*(\w*)\r\n\r\n", out)
     if matches is not None:
@@ -53,7 +50,7 @@ def get_cert_serial(cert_file):
 
 
 def get_stored_cert_serials(store):
-    '''
+    """
     Get all of the certificate serials in the specified store
 
     store
@@ -64,16 +61,16 @@ def get_stored_cert_serials(store):
     .. code-block:: bash
 
         salt '*' certutil.get_stored_cert_serials <store>
-    '''
-    cmd = "certutil.exe -store {0}".format(store)
-    out = __salt__['cmd.run'](cmd)
+    """
+    cmd = "certutil.exe -store {}".format(store)
+    out = __salt__["cmd.run"](cmd)
     # match serial numbers by header position to work with multiple languages
     matches = re.findall(r"={16}\r\n.*:\s*(\w*)\r\n", out)
     return matches
 
 
-def add_store(source, store, saltenv='base'):
-    '''
+def add_store(source, store, retcode=False, saltenv="base"):
+    """
     Add the given cert into the given Certificate Store
 
     source
@@ -83,6 +80,9 @@ def add_store(source, store, saltenv='base'):
     store
         The certificate store to add the certificate to
 
+    retcode
+        If true, return the retcode instead of stdout. Default is ``False``
+
     saltenv
         The salt environment to use this is ignored if the path
         is local
@@ -92,14 +92,17 @@ def add_store(source, store, saltenv='base'):
     .. code-block:: bash
 
         salt '*' certutil.add_store salt://cert.cer TrustedPublisher
-    '''
-    cert_file = __salt__['cp.cache_file'](source, saltenv)
-    cmd = "certutil.exe -addstore {0} {1}".format(store, cert_file)
-    return __salt__['cmd.run'](cmd)
+    """
+    cert_file = __salt__["cp.cache_file"](source, saltenv)
+    cmd = "certutil.exe -addstore {} {}".format(store, cert_file)
+    if retcode:
+        return __salt__["cmd.retcode"](cmd)
+    else:
+        return __salt__["cmd.run"](cmd)
 
 
-def del_store(source, store, saltenv='base'):
-    '''
+def del_store(source, store, retcode=False, saltenv="base"):
+    """
     Delete the given cert into the given Certificate Store
 
     source
@@ -109,6 +112,9 @@ def del_store(source, store, saltenv='base'):
     store
         The certificate store to delete the certificate from
 
+    retcode
+        If true, return the retcode instead of stdout. Default is ``False``
+
     saltenv
         The salt environment to use this is ignored if the path
         is local
@@ -118,8 +124,11 @@ def del_store(source, store, saltenv='base'):
     .. code-block:: bash
 
         salt '*' certutil.del_store salt://cert.cer TrustedPublisher
-    '''
-    cert_file = __salt__['cp.cache_file'](source, saltenv)
+    """
+    cert_file = __salt__["cp.cache_file"](source, saltenv)
     serial = get_cert_serial(cert_file)
-    cmd = "certutil.exe -delstore {0} {1}".format(store, serial)
-    return __salt__['cmd.run'](cmd)
+    cmd = "certutil.exe -delstore {} {}".format(store, serial)
+    if retcode:
+        return __salt__["cmd.retcode"](cmd)
+    else:
+        return __salt__["cmd.run"](cmd)
